==> homesitemaker-v0.4.1.tar.gz: homesitemaker/includes/left_table.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/config_site.php");
include ("images/skins/".$SKIN."/".$SKIN.".php");
include ("includes/languages/".$LANGUAGE."/homesite-includes-left_table.php");

$not_news=0;
echo "<td bgcolor=$COLOR3 valign=\"top\">";

echo "<div class=\"link2\"><a href=\"index.php?top_tab=1&num=$num\">".$TAB_1."</a></div>";
if ($TAB_11!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=1&section_type=1&num=$num\">".$TAB_11."</a></div>";
   if ($SECTION_TYPE_11!="news") $not_news++;
   }
if ($TAB_12!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=1&section_type=2&num=$num\">".$TAB_12."</a></div>";
   if ($SECTION_TYPE_12!="news") $not_news++;
   }
if ($TAB_13!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=1&section_type=3&num=$num\">".$TAB_13."</a></div>";
   if ($SECTION_TYPE_13!="news") $not_news++;
   }
if ($TAB_14!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=1&section_type=4&num=$num\">".$TAB_14."</a></div>";
   if ($SECTION_TYPE_14!="news") $not_news++;
   }

echo "<div class=\"link2\"><a href=\"index.php?top_tab=2&num=$num\">".$TAB_2."</a></div>";
if ($TAB_21!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=2&section_type=1&num=$num\">".$TAB_21."</a></div>";
   if ($SECTION_TYPE_21!="news") $not_news++;
   }
if ($TAB_22!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=2&section_type=2&num=$num\">".$TAB_22."</a></div>";
   if ($SECTION_TYPE_22!="news") $not_news++;
   }
if ($TAB_23!="NO") 
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=2&section_type=3&num=$num\">".$TAB_23."</a></div>";
   if ($SECTION_TYPE_23!="news") $not_news++;
   }
if ($TAB_24!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=2&section_type=4&num=$num\">".$TAB_24."</a></div>";
   if ($SECTION_TYPE_24!="news") $not_news++;
   }

echo "<div class=\"link2\"><a href=\"index.php?top_tab=3&num=$num\">".$TAB_3."</a></div>";
if ($TAB_31!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=3&section_type=1&num=$num\">".$TAB_31."</a></div>";
   if ($SECTION_TYPE_31!="news") $not_news++;
   }
if ($TAB_32!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=3&section_type=2&num=$num\">".$TAB_32."</a></div>";
   if ($SECTION_TYPE_32!="news") $not_news++;
   }
if ($TAB_33!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=3&section_type=3&num=$num\">".$TAB_33."</a></div>";
   if ($SECTION_TYPE_33!="news") $not_news++;
   }
if ($TAB_34!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=3&section_type=4&num=$num\">".$TAB_34."</a></div>";
   if ($SECTION_TYPE_34!="news") $not_news++;
   }

echo "<div class=\"link2\"><a href=\"index.php?top_tab=4&num=$num\">".$TAB_4."</a></div>";
if ($TAB_41!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=4&section_type=1&num=$num\">".$TAB_41."</a></div>";
   if ($SECTION_TYPE_41!="news") $not_news++;
   }
if ($TAB_42!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=4&section_type=2&num=$num\">".$TAB_42."</a></div>";
   if ($SECTION_TYPE_42!="news") $not_news++;
   }
if ($TAB_43!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=4&section_type=3&num=$num\">".$TAB_43."</a></div>";
   if ($SECTION_TYPE_43!="news") $not_news++;
   }
if ($TAB_44!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=4&section_type=4&num=$num\">".$TAB_44."</a></div>";
   if ($SECTION_TYPE_44!="news") $not_news++;
   }

if ($P_ITEMS!="NO")
   {
   include ("includes/db_connect.php");
   $pending_albums=mysql_query("SELECT id_album FROM album WHERE status='0'", $db);
   $num_pending_albums=mysql_num_rows($pending_albums);
   $pending_news=mysql_query("SELECT id_info FROM info WHERE status='1'", $db);
   $num_pending_news=mysql_num_rows($pending_news);
   echo "<br><hr color=\"$LPTLC\" size=\"$LPTLS\">".
        "<span class=\"text2b\">$LTEXT1001</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1002 (".$num_pending_albums.")</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1003 (".$num_pending_news.")</span><br>";
   }
if ($STATS!="NO")
   {
   include ("includes/db_connect.php");
   $users=mysql_query("SELECT id_user FROM users", $db);
   $num_users=mysql_num_rows($users);
   $infos=mysql_query("SELECT id_info FROM info", $db);
   $num_infos=mysql_num_rows($infos);
   $pending_news=mysql_query("SELECT id_info FROM info WHERE status='1'", $db);
   $num_pending_news=mysql_num_rows($pending_news);
   $not_showed_infos=15-$not_news;
   $num_news=$num_infos-$not_news-$num_pending_news-$not_showed_infos;
   $comments=mysql_query("SELECT id_comment FROM comment", $db);
   $num_comments=mysql_num_rows($comments);
   $albums=mysql_query("SELECT id_album FROM album", $db);
   $num_albums=mysql_num_rows($albums);
   $pending_albums=mysql_query("SELECT id_album FROM album WHERE status='0'", $db);
   $num_pending_albums=mysql_num_rows($pending_albums);
   $num_published_albums=$num_albums-$num_pending_albums;
   echo "<br><hr color=\"$LPTLC\" size=\"$LPTLS\">".
        "<span class=\"text2b\">$LTEXT1004</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1005 (".$num_users.")</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1006 (".$num_news.")</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1007 (".$num_published_albums.")</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1008 (".$num_comments.")</span><br>";
   }
   $news=0;
   for ($tab = 1; $tab <= 4; $tab++ )
       {
       for ($section = 1; $section <= 4; $section++)
           {
           $section_type_str = "SECTION_TYPE_"."$tab"."$section";
           $section_name_str = "TAB_"."$tab"."$section";
           if ($$section_type_str == "news") // Shows the RSS logo only if one news section exists
              {
              $news++;
              $top_tab=$tab;
              $section_type=$section;
              }
           }
       }
   if ($news>0) echo "<br><hr color=\"$LPTLC\" size=\"$LPTLS\">".
                     "<center><br><span class=\"text1b\">$LTEXT1009<br></center>".
                     "<center><a href=\"$URL/index.php?top_tab=$top_tab&section_type=$section_type&task=rss_feeds&num=$num\"><img border=0 src=\"images/logos/rss20.png\"></a></span></center>";

echo "</td>";
?>

==> homesitemaker-v0.4.4.tar.gz: homesitemaker/includes/left_table.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/config_site.php");
include ("images/skins/".$SKIN."/".$SKIN.".php");
include ("includes/languages/".$LANGUAGE."/homesite-includes-left_table.php");
$fondo=$COLOR;
if ($COLOR=="B" || $COLOR=="Y" || $COLOR=="M" || $COLOR=="G")
   {
   if ($COLOR=="B") $fondo=$COLOR1;
   if ($COLOR=="Y") $fondo=$COLOR2;
   if ($COLOR=="M") $fondo=$COLOR3;
   if ($COLOR=="G") $fondo=$COLOR4;
   }

$not_news=0;
echo "<td bgcolor=$fondo valign=\"top\">";

echo "<div class=\"link2\"><a href=\"index.php?top_tab=1&num=$num\">".$TAB_1."</a></div>";
if ($TAB_11!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=1&section_type=1&num=$num\">".$TAB_11."</a></div>";
   if ($SECTION_TYPE_11!="news") $not_news++;
   }
if ($TAB_12!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=1&section_type=2&num=$num\">".$TAB_12."</a></div>";
   if ($SECTION_TYPE_12!="news") $not_news++;
   }
if ($TAB_13!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=1&section_type=3&num=$num\">".$TAB_13."</a></div>";
   if ($SECTION_TYPE_13!="news") $not_news++;
   }
if ($TAB_14!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=1&section_type=4&num=$num\">".$TAB_14."</a></div>";
   if ($SECTION_TYPE_14!="news") $not_news++;
   }

echo "<div class=\"link2\"><a href=\"index.php?top_tab=2&num=$num\">".$TAB_2."</a></div>";
if ($TAB_21!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=2&section_type=1&num=$num\">".$TAB_21."</a></div>";
   if ($SECTION_TYPE_21!="news") $not_news++;
   }
if ($TAB_22!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=2&section_type=2&num=$num\">".$TAB_22."</a></div>";
   if ($SECTION_TYPE_22!="news") $not_news++;
   }
if ($TAB_23!="NO") 
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=2&section_type=3&num=$num\">".$TAB_23."</a></div>";
   if ($SECTION_TYPE_23!="news") $not_news++;
   }
if ($TAB_24!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=2&section_type=4&num=$num\">".$TAB_24."</a></div>";
   if ($SECTION_TYPE_24!="news") $not_news++;
   }

echo "<div class=\"link2\"><a href=\"index.php?top_tab=3&num=$num\">".$TAB_3."</a></div>";
if ($TAB_31!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=3&section_type=1&num=$num\">".$TAB_31."</a></div>";
   if ($SECTION_TYPE_31!="news") $not_news++;
   }
if ($TAB_32!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=3&section_type=2&num=$num\">".$TAB_32."</a></div>";
   if ($SECTION_TYPE_32!="news") $not_news++;
   }
if ($TAB_33!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=3&section_type=3&num=$num\">".$TAB_33."</a></div>";
   if ($SECTION_TYPE_33!="news") $not_news++;
   }
if ($TAB_34!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=3&section_type=4&num=$num\">".$TAB_34."</a></div>";
   if ($SECTION_TYPE_34!="news") $not_news++;
   }

echo "<div class=\"link2\"><a href=\"index.php?top_tab=4&num=$num\">".$TAB_4."</a></div>";
if ($TAB_41!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=4&section_type=1&num=$num\">".$TAB_41."</a></div>";
   if ($SECTION_TYPE_41!="news") $not_news++;
   }
if ($TAB_42!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=4&section_type=2&num=$num\">".$TAB_42."</a></div>";
   if ($SECTION_TYPE_42!="news") $not_news++;
   }
if ($TAB_43!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=4&section_type=3&num=$num\">".$TAB_43."</a></div>";
   if ($SECTION_TYPE_43!="news") $not_news++;
   }
if ($TAB_44!="NO")
   {
   echo "<div class=\"link1\">&nbsp;- <a href=\"index.php?top_tab=4&section_type=4&num=$num\">".$TAB_44."</a></div>";
   if ($SECTION_TYPE_44!="news") $not_news++;
   }

if ($P_ITEMS!="NO")
   {
   include ("includes/db_connect.php");
   $pending_albums=mysql_query("SELECT id_album FROM album WHERE status='0'", $db);
   $num_pending_albums=mysql_num_rows($pending_albums);
   $pending_news=mysql_query("SELECT id_info FROM info WHERE status='1'", $db);
   $num_pending_news=mysql_num_rows($pending_news);
   echo "<br><hr color=\"$LPTLC\" size=\"$LPTLS\">".
        "<span class=\"text2b\">$LTEXT1001</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1002 (".$num_pending_albums.")</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1003 (".$num_pending_news.")</span><br>";
   }
if ($STATS!="NO")
   {
   include ("includes/db_connect.php");
   $users=mysql_query("SELECT id_user FROM users", $db);
   $num_users=mysql_num_rows($users);
   $infos=mysql_query("SELECT id_info FROM info", $db);
   $num_infos=mysql_num_rows($infos);
   $pending_news=mysql_query("SELECT id_info FROM info WHERE status='1'", $db);
   $num_pending_news=mysql_num_rows($pending_news);
   $not_showed_infos=15-$not_news;
   $num_news=$num_infos-$not_news-$num_pending_news-$not_showed_infos;
   $comments=mysql_query("SELECT id_comment FROM comment", $db);
   $num_comments=mysql_num_rows($comments);
   $albums=mysql_query("SELECT id_album FROM album", $db);
   $num_albums=mysql_num_rows($albums);
   $pending_albums=mysql_query("SELECT id_album FROM album WHERE status='0'", $db);
   $num_pending_albums=mysql_num_rows($pending_albums);
   $num_published_albums=$num_albums-$num_pending_albums;
   echo "<br><hr color=\"$LPTLC\" size=\"$LPTLS\">".
        "<span class=\"text2b\">$LTEXT1004</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1005 (".$num_users.")</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1006 (".$num_news.")</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1007 (".$num_published_albums.")</span><br>".
        "<span class=\"text1\">&nbsp;- $LTEXT1008 (".$num_comments.")</span><br>";
   }
   $news=0;
   for ($tab = 1; $tab <= 4; $tab++ )
       {
       for ($section = 1; $section <= 4; $section++)
           {
           $section_type_str = "SECTION_TYPE_"."$tab"."$section";
           $section_name_str = "TAB_"."$tab"."$section";
           if ($$section_type_str == "news") // Shows the RSS logo only if one news section exists
              {
              $news++;
              $top_tab=$tab;
              $section_type=$section;
              }
           }
       }
   if ($news>0) echo "<br><hr color=\"$LPTLC\" size=\"$LPTLS\">".
                     "<center><br><span class=\"text1b\">$LTEXT1009<br></center>".
                     "<center><a href=\"$URL/index.php?top_tab=$top_tab&section_type=$section_type&task=rss_feeds&num=$num\"><img border=0 src=\"images/logos/rss20.png\"></a></span></center>";

echo "</td>";
?>
